Learn R Programming

genlogis (version 1.0.2)

distrib_sk: The Generalized logistic distribution with skewness

Description

Density, distribution function, quantile function and random generation a generalized logistic distribution with skewness.

Usage

pgenlog_sk(
  q,
  a = sqrt(2/pi),
  b = 0.5,
  p = 2,
  mu = 0,
  skew = 0.5,
  lower.tail = TRUE
)

dgenlog_sk(x, a = sqrt(2/pi), b = 0.5, p = 2, mu = 0, skew = 0.5)

qgenlog_sk( k, a = sqrt(2/pi), b = 0.5, p = 2, mu = 0, skew = 0.5, lower.tail = TRUE )

rgenlog_sk(n, a = sqrt(2/pi), b = 0.5, p = 2, mu = 0, skew = 0.5)

Value

dgenlog_sk gives the density, pgenlog_sk gives the distribution function, qgenlog_sk gives the quantile function, and rgenlog_sk generates random deviates.

The length of the result is determined by n for rgenlog_sk, and is the maximum of the lengths of the numerical arguments for the other functions.

Arguments

a, b, p

parameters \(\le 0\), with restrictions.*

mu

mu parameter

skew

skewness parameter limited to the interval (-1, 1)

lower.tail

logical; if TRUE (default), probabilities are \(P[X \le x]\) otherwise, \(P[X > x]\).

x, q

vector of quantiles.

k

vector of probabilities.

n

number of observations. If length(n) > 1, the length is taken to be the number required

Details

The used distribution for this package is given by: $$f(x) = 2*((a + b*(1+p)*(abs(x-mu)^p))*exp(-(x-mu)*(a+b*(abs(x-mu)^p))))/ ((exp(-(x-mu)*(a + b* (abs(x-mu)^p)))+1)^2) * ((exp(-(skew*(x-mu))*(a+b*(abs(skew*(x-mu))^p)))+1)^(-1)) $$

The default values for a, b, p and mu produces a function with mean 0 and variance close to 1.

*Restrictions:

If p equals to 0, b or a must be 0 otherwise there is identifiability problem.

The distribution is not defined for a and b equal to 0 simultaneously.

References

Rathie, P. N. and Swamee, P. K (2006) On a new invertible generalized logistic distribution approximation to normal distribution, Technical Research Report in Statistics, 07/2006, Dept. of Statistics, Univ. of Brasilia, Brasilia, Brazil.

Azzalini, A. (1985) A class of distributions which includes the normal ones. Scandinavian Journal of Statistics.

Examples

Run this code
pgenlog_sk(0.5) 
curve(dgenlog_sk(x), xlim = c(-3,3)) 

rgenlog_sk(100) 

qgenlog_sk(0.95)


Run the code above in your browser using DataLab