Return a list of components as constrOptim \(for more information, check this function\)
with some extras:
par The best set of parameters found.
value The value of the loglikelihood function corresponding to par.
counts A two-element integer vector giving the number of calls to the likelihood
function and BFGS respectively. This excludes those calls needed to
compute the Hessian, and any calls to likelihood function to compute a
finite-difference approximation to the gradient.
convergence An integer code. 0 indicates successful completion, 1 indicates that
the iteration limit maxit had been reached. For more errors help(constrOptim).
message A character string giving any additional information returned by the optimizer,
or NULL.
outer.iterations gives the number of outer iterations (calls to optim).
barrier.value giving the value of the barrier function at the optimum.
For hessian = T add:
hessian A symmetric matrix giving an estimate of the (negative) Hessian at the solution found.
Note that this is the Hessian of the unconstrained problem even if the box
constraints are active.
bounds Return the best parameters found and the upper and lower bounds for the estimation.